@@ -8,8 +8,10 @@ parser.add_argument("-o", "--output", help="Path to where the output model shoul
                                            "directory as input file.", default=None)
 parser.add_argument("-H", "--heavy_chain", help="Heavy chain ID for input file. (Default is H)", default="H")
 parser.add_argument("-L", "--light_chain", help="Light chain ID for input file. (Default is L)", default="L")
+parser.add_argument('-M', "--model", help="Model to use for predictions. (Default is chothia)", default="chothia")
 parser.add_argument("--confidence_score", help="Print confidence score for each loop", default=False,
                     action="store_true")
+parser.add_argument("-q", "--quiet", help="Stop ABlooper from printing warnings.", default=False, action="store_true")
 
 if openmm_available or rosetta_available:
     parser.add_argument("-s", "--side_chains", help="Predict side chains and refine loop geometry",
@@ -29,8 +31,8 @@ def main():
         side_chains = False
 
     refine_method = "pyrosetta" if (args.rosetta_refine if rosetta_available else False) else "openmm"
-    predictor = CDR_Predictor(args.file_path, chains=(args.heavy_chain, args.light_chain), refine=side_chains,
-                              refine_method=refine_method)
+    predictor = CDR_Predictor(args.file_path, chains=(args.heavy_chain, args.light_chain), model=args.model, refine=side_chains,
+                              refine_method=refine_method, warn=(not args.quiet))
     output_file = args.output
 
     if output_file is None:
